@@ -12,6 +12,7 @@ from cytoolz.curried import (
     curry,
     partitionby,
 )
+from genomoncology.parse.doctypes import is_header
 from specd import create_app
 
 from genomoncology import kms
@@ -41,7 +42,7 @@ DEFAULT_SPECD_PATH = os.path.join(
     os.path.dirname(__file__), "../../gosdk/specs/"
 )
 
-VERSION = "0.9.5"
+VERSION = "0.9.6"
 COPYRIGHT = "Copyright: GenomOncology, LLC"
 
 
@@ -266,6 +267,30 @@ def from_maf(state, columns):
     return [sources.MAFSource(columns=columns, build=state.build)]
 
 
+@gocli.command()
+@click.argument("data_set", type=str)
+@click.argument("data_set_version", type=str)
+@options.size_option
+@options.pass_state
+def load_hotspots(state, data_set="DATASET", data_set_version="DSV"):
+    create_function = kms.create_sync_processor
+    sdk_function = kms.annotations.hotspot_annotate
+
+    return [
+        filter(is_header),
+        partition_all(
+            state.batch_size
+        ),  # annotate calls is GET, hardcoded batch size
+        create_function(
+            state,
+            sdk_function,
+            data_set=data_set,
+            data_set_version=data_set_version,
+        ),
+        concat,
+    ]
+
+
 @gocli.command()
 @click.option(
     "--fields",
@@ -594,6 +619,7 @@ def load_features(state, workers):
     type=int,
     default=10,
 )
+@options.timeout_option
 @options.size_option
 @options.build_option
 @options.pass_state
