@@ -41,6 +41,18 @@ def _process_vcf_info(vcf_dict):
             ][0].split("=")[1]
         else:
             vcf_dict[k]["AA"] = "None"
+        if "LEGACY_ID" in v["INFO"]:
+            vcf_dict[k]["LEGACY_ID"] = [
+                x for x in v["INFO"].split(";") if x[:9] == "LEGACY_ID"
+            ][0].split("=")[1]
+        else:
+            vcf_dict[k]["LEGACY_ID"] = "None"
+        if "GENE" in v["INFO"]:
+            vcf_dict[k]["GENE"] = [[
+                x for x in v["INFO"].split(";") if x[:4] == "GENE"
+            ][0].split("=")[1]]
+        else:
+            vcf_dict[k]["Gene"] = []
     return vcf_dict
 
 
@@ -178,7 +190,9 @@ class AggregatedCOSMICSources(LazyFileSource):
                     "Histology subtype 2",
                     "Histology subtype 3",
                     "Genome-wide screen",
-                    "Mutation ID",
+                    "GENOMIC_MUTATION_ID",
+                    "LEGACY_MUTATION_ID",
+                    "MUTATION_ID",
                     "Mutation CDS",
                     "Mutation AA",
                     "Mutation Description",
@@ -197,6 +211,9 @@ class AggregatedCOSMICSources(LazyFileSource):
                     "Sample Type",
                     "Tumour origin",
                     "Age",
+                    "HGVSP",
+                    "HGVSC",
+                    "HGVSG",
                 ],
                 delimiter="\t",
                 include_header=False,
@@ -239,7 +256,7 @@ class AggregatedCOSMICSources(LazyFileSource):
         }
 
     def cosmic_key_value(self, element):
-        return element["Mutation ID"]
+        return element["GENOMIC_MUTATION_ID"]
 
     def merge_key_value(self, element):
         return "-".join(
@@ -267,7 +284,7 @@ class AggregatedCOSMICSources(LazyFileSource):
 
     def merge_aggregate_value(self, acc, x):
         hold_d = copy.deepcopy(acc)
-        for key in ["#CHROM", "POS", "REF", "ALT"]:
+        for key in ["#CHROM", "POS", "REF", "ALT", "GENE"]:
             if key not in hold_d:
                 hold_d[key] = x[key]
         for key in [
@@ -278,6 +295,7 @@ class AggregatedCOSMICSources(LazyFileSource):
             "RESISTANCE_MUTATION",
             "CDS",
             "AA",
+            "LEGACY_ID",
         ]:
             if key not in hold_d:
                 hold_d[key] = [x[key]]
