@@ -175,7 +175,6 @@ class ClinvarXMLSource:
         return result
 
     def get_alteration_string(self, interpreted_record):
-        gene_names = []
         try:
             protein_change = (
                 interpreted_record.find(SIMPLE_ALLELE)
@@ -184,21 +183,30 @@ class ClinvarXMLSource:
             )
         except Exception:
             protein_change = None
+        genes, is_submitted = self.get_genes(interpreted_record)
+        if len(genes) > 0 and is_submitted and protein_change:
+            gene_name = genes[0]
+            return f"{gene_name} {protein_change}"
+        else:
+            return None
+
+    def get_genes(self, interpreted_record):
+        """
+            Returns list of gene names and
+            whether the gene was submitted or not.
+        """
         try:
             genes = (
                 interpreted_record.find(SIMPLE_ALLELE)
                 .find(GENE_LIST)
                 .findall(GENE)
             )
+            for gene in genes:
+                if gene.attrib.get("Source") == "submitted":
+                    return [gene.attrib.get("Symbol")], True
+            return [g.attrib.get("Symbol") for g in genes], False
         except Exception:
-            genes = None
-        if genes and protein_change:
-            for g in genes:
-                gene = g.attrib.get("Symbol")
-                gene_names.append(f"{gene} {protein_change}")
-                return "".join(gene_names)
-        else:
-            return None
+            return [], False
 
     def create_csra(self, interpreted_record):
         try:
@@ -214,21 +222,20 @@ class ClinvarXMLSource:
                     if sl.attrib.get(ASSEMBLY) == GRCH_37
                 ]
                 for sl in valid_sequence_locations:
-                    chr, positionVCF = (
+                    chr, pos = (
                         sl.attrib.get("Chr"),
                         sl.attrib.get("positionVCF"),
                     )
-                    referenceAllele, alternateAllele = (
+                    ref, alt = (
                         sl.attrib.get("referenceAlleleVCF"),
                         sl.attrib.get("alternateAlleleVCF"),
                     )
-                    if referenceAllele == alternateAllele or not all(
-                        [chr, positionVCF, referenceAllele, alternateAllele]
+                    if ref == alt or not all(
+                        [chr, pos, ref, alt]
                     ):
                         return None
                     else:
-                        return f"chr{chr}|{positionVCF}|"\
-                               f"{referenceAllele}|{alternateAllele}|GRCh37"
+                        return f"chr{chr}|{pos}|{ref}|{alt}|GRCh37"
             else:
                 return None
         except Exception:
@@ -328,12 +335,16 @@ class ClinvarXMLSource:
         clnvi = [self.create_combined_xref(interpreted_record)]
         clndn = self.get_interpreted_conditions(rcv_accessions)
         gene_protein_change = self.get_alteration_string(interpreted_record)
-        alteration_string = (
-            gene_protein_change
-            if gene_protein_change
-            else self.create_csra(interpreted_record)
-        )
-        hgvs_g = self.create_csra(interpreted_record)
+        csra = self.create_csra(interpreted_record)
+        alteration_string = gene_protein_change
+        hgvs_g = csra
+        csra_array = csra.split("|") if csra else []
+        chromosome = None
+        position = None
+        if len(csra_array) > 1:
+            chromosome = csra_array[0].replace("chr", "")
+            position = csra_array[1]
+        genes, _ = self.get_genes(interpreted_record)
 
         # build top-level result dict with fields that could be parsed
         record = {}
@@ -351,6 +362,12 @@ class ClinvarXMLSource:
             record["alteration__string"] = alteration_string
         if hgvs_g:
             record["hgvs_g"] = hgvs_g
+        if chromosome:
+            record["chr"] = chromosome
+        if position:
+            record["position"] = position
+        if len(genes) > 0:
+            record["gene"] = genes
         record = self.iterate_individual_submissions(
             clinical_assertions, record, interpreted_record
         )
